==> magpie-data-0.10.2-sources.jar: io/openraven/magpie/data/azure/sql/SQLServer.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.azure.sql;

import io.openraven.magpie.data.aws.shared.PayloadUtils;
import io.openraven.magpie.data.azure.AzureResource;
import software.amazon.awssdk.services.rds.model.DBInstance;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = SQLServer.TABLE_NAME)
public class SQLServer extends AzureResource {

  protected static final String TABLE_NAME = "azuresqlserver";
  public static final String RESOURCE_TYPE = "Azure::SQL::Server";

  @SuppressWarnings("unused")
  public SQLServer() {
    this.resourceType = RESOURCE_TYPE;
  }

}

==> magpie-data-0.11.2-sources.jar: io/openraven/magpie/data/azure/sql/SQLServer.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.azure.sql;

import io.openraven.magpie.data.aws.shared.PayloadUtils;
import io.openraven.magpie.data.azure.AzureResource;
import software.amazon.awssdk.services.rds.model.DBInstance;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = SQLServer.TABLE_NAME)
public class SQLServer extends AzureResource {

  protected static final String TABLE_NAME = "azuresqlserver";
  public static final String RESOURCE_TYPE = "Azure::SQL::Server";

  @SuppressWarnings("unused")
  public SQLServer() {
    this.resourceType = RESOURCE_TYPE;
  }

}
